package edu.byu.cs.fragmentexample.ui;

import android.content.Intent;
import android.os.Bundle;
import androidx.fragment.app.FragmentActivity;
import androidx.fragment.app.FragmentManager;
import android.view.View;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;

import edu.byu.cs.fragmentexample.R;
import edu.byu.cs.fragmentexample.model.Address;
import edu.byu.cs.fragmentexample.model.Order;

public class OrderInfoActivity extends FragmentActivity {

    static final String EXTRA_RESULT = "result";

    private AddressFragment shippingAddressFragment;
    private AddressFragment billingAddressFragment;
    private CheckBox checkBox;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_order_info);

        checkBox = findViewById(R.id.checkBox);
        checkBox.setChecked(true);
        checkBox.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                FragmentManager fragmentManager = getSupportFragmentManager();

                if (checkBox.isChecked()) {
                    // Remove the billingAddressFragment. We no longer need it
                    // (because the billing address is the same as the shipping address)
                    fragmentManager.beginTransaction()
                            .remove(billingAddressFragment)
                            .commit();
                } else {
                    // Create the billingAddressFragment. The billing address is now
                    // different than the shipping address
                    billingAddressFragment = createAddressFragment(getString(R.string.billingAddressTitle));
                    fragmentManager.beginTransaction()
                            .add(R.id.billingFrameLayout, billingAddressFragment)
                            .commit();
                }
            }
        });

        Button button = findViewById(R.id.button);
        button.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                onButtonClicked();
            }
        });

        FragmentManager fm = this.getSupportFragmentManager();
        shippingAddressFragment = (AddressFragment) fm.findFragmentById(R.id.shippingFrameLayout);
        if (shippingAddressFragment == null) {
            shippingAddressFragment = createAddressFragment(getString(R.string.shippingAddressTitle));
            fm.beginTransaction()
                    .add(R.id.shippingFrameLayout, shippingAddressFragment)
                    .commit();
        }

        // Don't add billingAddressFragment. By default the billing address is the
        // same as the shipping address (see the onCheckChanged method)
    }

    private AddressFragment createAddressFragment(String title) {
        AddressFragment fragment = new AddressFragment();

        Bundle args = new Bundle();
        args.putString(AddressFragment.ARG_TITLE, title);
        fragment.setArguments(args);

        return fragment;
    }

    private void onButtonClicked() {
        returnResult();
        this.finish();
    }

    private void returnResult() {
        Address shippingAddress = shippingAddressFragment.getAddress();

        Address billingAddress = null;
        if (!checkBox.isChecked()) {
            billingAddress = billingAddressFragment.getAddress();
        }

        Order order = new Order();
        order.setShippingAddress(shippingAddress);
        order.setBillingAddress(billingAddress);

        Intent intent = new Intent();
        intent.putExtra(EXTRA_RESULT, order);
        setResult(RESULT_OK, intent);
    }
}